@@ -5,6 +5,7 @@ A simple twisted STOMP message sender.
 License: http://www.apache.org/licenses/LICENSE-2.0
 
 """
+from __future__ import print_function
 import logging
 
 from twisted.internet import reactor
@@ -117,13 +118,13 @@ class StompClientFactory(ReconnectingClientFactory):
     def clientConnectionLost(self, connector, reason):
         """Lost connection
         """
-        print 'Lost connection.  Reason:', reason
+        print('Lost connection.  Reason:', reason)
     
     
     def clientConnectionFailed(self, connector, reason):
         """Connection failed
         """
-        print 'Connection failed. Reason:', reason        
+        print('Connection failed. Reason:', reason)        
         ReconnectingClientFactory.clientConnectionFailed(self, connector, reason)
 
 
